#
# This is the SPEC file for creating binary and source RPMs for the VMs.
#
#
# The Qubes OS Project, http://www.qubes-os.org
#
# Copyright (C) 2011  Marek Marczykowski <marmarek@invisiblethingslab.com>
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
#
#

# enable python3 by default
%bcond_without python3

# python2 is not available on RHEL > 7 and not needed on Fedora > 28
%if 0%{?rhel} > 7 || 0%{?fedora} > 28
# disable python2 by default
%bcond_with python2
%else
%bcond_without python2
%endif


Name:		qubes-gpg-split-dom0
Version:	2.0.63
Release:	1%{dist}
Summary:    Qubes policy for gpg split

Group:		Qubes
Vendor:		Invisible Things Lab
License:	GPL
URL:		http://www.qubes-os.org

BuildRequires: make
%if %{with python2}
BuildRequires: python-setuptools
BuildRequires: python2-rpm-macros
%endif
%if %{with python3}
BuildRequires: python3-rpm-macros
BuildRequires: python3-setuptools
BuildRequires: python3-devel
%endif
Requires:	gpg

Source0: qubes-gpg-split-%{version}.tar.gz

%description

%prep
%setup -q -n qubes-gpg-split-%{version}

%install
rm -rf $RPM_BUILD_ROOT
install -m 0664 -D qubes.Gpg.policy $RPM_BUILD_ROOT/etc/qubes-rpc/policy/qubes.Gpg
install -m 0664 -D qubes.GpgImportKey.policy $RPM_BUILD_ROOT/etc/qubes-rpc/policy/qubes.GpgImportKey
%{?with_python2:make -C tests install-dom0-py2 DESTDIR=$RPM_BUILD_ROOT PYTHON2=%{__python2}}
%{?with_python3:make -C tests install-dom0-py3 DESTDIR=$RPM_BUILD_ROOT PYTHON2=%{__python3}}

%clean
rm -rf $RPM_BUILD_ROOT

%files
%config(noreplace) %attr(0664,root,qubes) /etc/qubes-rpc/policy/qubes.Gpg
%config(noreplace) %attr(0664,root,qubes) /etc/qubes-rpc/policy/qubes.GpgImportKey
%if %{with python2}
%dir %{python2_sitelib}/splitgpg-*.egg-info
%{python2_sitelib}/splitgpg-*.egg-info/*
%{python2_sitelib}/splitgpg
%endif
%if %{with python3}
%dir %{python3_sitelib}/splitgpg-*.egg-info
%{python3_sitelib}/splitgpg-*.egg-info/*
%{python3_sitelib}/splitgpg
%endif

%changelog
* Sat Aug 06 2022 Qubes OS Team <qubes-devel@googlegroups.com>
- For complete changelog see: https://github.com/QubesOS/qubes-app-linux-split-gpg.git

* Sat Aug 06 2022 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - fa04403
- version 2.0.63

* Mon Aug 01 2022 Demi Marie Obenour <demi@invisiblethingslab.com> - 67cb2bc
- Force --exit-on-status-write-error

* Mon Aug 01 2022 Demi Marie Obenour <demi@invisiblethingslab.com> - ab857f6
- Prevent GnuPG from using a closed file descriptor

* Mon Aug 01 2022 Demi Marie Obenour <demi@invisiblethingslab.com> - 9d35724
- Force batch mode

* Mon Aug 01 2022 Demi Marie Obenour <demi@invisiblethingslab.com> - 3c52800
- Disallow --command-fd

* Fri Jul 29 2022 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 434beb8
- version 2.0.62

* Fri Jul 29 2022 Demi Marie Obenour <demi@invisiblethingslab.com> - 315c171
- Emulate --quiet in terms of -q

* Wed Jul 27 2022 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - cca9708
- version 2.0.61

* Wed Jul 27 2022 Demi Marie Obenour <demi@invisiblethingslab.com> - 26add28
- Allow "qubes-gpg-client --verify - a.sig"

* Wed Jul 27 2022 Demi Marie Obenour <demi@invisiblethingslab.com> - 614cd28
- Check that standard streams are open

* Wed Jul 27 2022 Demi Marie Obenour <demi@invisiblethingslab.com> - f5d08b7
- Mark received file descriptors CLOEXEC

* Wed Jul 27 2022 Demi Marie Obenour <demi@invisiblethingslab.com> - 529ad8c
- Make is_client a const global variable

* Wed Jul 27 2022 Demi Marie Obenour <demi@invisiblethingslab.com> - 914c2f9
- Refuse to use the same FD for both reading and writing

* Wed Jul 27 2022 Demi Marie Obenour <demi@invisiblethingslab.com> - 8d33d4d
- Use common code for file descriptor lists

* Sun Jul 10 2022 Demi Marie Obenour <demi@invisiblethingslab.com> - 54cee94
- Allow exporting public keyring backups

* Sat Jul 09 2022 Demi Marie Obenour <demi@invisiblethingslab.com> - f59430f
- Avoid dropping a trailing empty string

* Sat Jul 09 2022 Demi Marie Obenour <demi@invisiblethingslab.com> - 56f8076
- Do not send argv[0] to server

* Sat Jul 09 2022 Demi Marie Obenour <demi@invisiblethingslab.com> - 7d59f75
- Fix cast to a potentially-misaligned pointer

* Sat Jul 09 2022 Demi Marie Obenour <demi@invisiblethingslab.com> - 2a52a8e
- Ensure that argc is never 0

* Sat Jul 09 2022 Demi Marie Obenour <demi@invisiblethingslab.com> - 5a936a3
- Avoid UBSAN splat on max-length input

* Sat Jul 09 2022 Demi Marie Obenour <demi@invisiblethingslab.com> - 6c504d3
- Fix misleading comments

* Fri Jul 08 2022 Demi Marie Obenour <demi@invisiblethingslab.com> - 23aa560
- Allow --show-session-key

* Thu Jun 30 2022 Demi Marie Obenour <demi@invisiblethingslab.com> - 52a34bc
- Properly NULL-terminate argument list

* Tue Jun 28 2022 Demi Marie Obenour <demi@invisiblethingslab.com> - 15e93bf
- Do not ignore -q and --quiet

* Mon Jun 20 2022 Demi Marie Obenour <demi@invisiblethingslab.com> - df14681
- Allow --export-ownertrust

* Mon Jun 13 2022 Demi Marie Obenour <demi@invisiblethingslab.com> - 37139cf
- gpg-client: check for too many file names

* Sun Jun 05 2022 Demi Marie Obenour <demi@invisiblethingslab.com> - 3a300ec
- Have bash choose an unused file descriptor

* Sun Jun 05 2022 Demi Marie Obenour <demi@invisiblethingslab.com> - 44d6ed0
- Avoid hang due to premature file descriptor close

* Mon May 30 2022 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - c5316c9
- version 2.0.60

* Thu May 26 2022 Demi Marie Obenour <demi@invisiblethingslab.com> - 754e16e
- Allow --list-options show-sig-subpackets

* Mon May 09 2022 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - bd743ea
- version 2.0.59

* Mon May 09 2022 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - bd9002a
- .qubesbuilder: replace 'spec' by 'build'

* Mon May 09 2022 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - e5a5a51
- tests: really just sign in test_010_send_receive_signed_only

* Mon May 09 2022 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - f4265a7
- tests: adjust message view in Evolution

* Mon May 09 2022 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 68cb2d9
- tests: close Evolution settings via xdotool

* Mon May 09 2022 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 5d6dfd4
- tests: update Evolution test for newer settings dialog layout

* Fri Apr 29 2022 Demi Marie Obenour <demi@invisiblethingslab.com> - 7889084
- Allow show-photos as a list or verify option

* Mon Apr 18 2022 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - 5daed1f
- Add Qubes Builder v2 integration

* Fri Apr 15 2022 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - 18ce4f4
- Drop Travis CI

* Sat Apr 02 2022 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 338d3c4
- version 2.0.58

* Sat Mar 26 2022 Demi Marie Obenour <demi@invisiblethingslab.com> - c03c30a
- Fix list and verify option processing

* Sat Mar 26 2022 Demi Marie Obenour <demi@invisiblethingslab.com> - c4a180f
- Drop --pgp2

* Sat Mar 26 2022 Demi Marie Obenour <demi@invisiblethingslab.com> - ea7df21
- Reject options ignored by the wrapper script

* Sun Mar 06 2022 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - a652de5
- test: avoid false negative from sending status dialog

* Mon Feb 28 2022 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - bd3b0bf
- version 2.0.57

* Sun Feb 27 2022 Demi Marie Obenour <demi@invisiblethingslab.com> - b5c4aed
- Allow --attribute-fd

* Sun Feb 27 2022 Demi Marie Obenour <demi@invisiblethingslab.com> - 72bab32
- Fix remaining hangs

* Sun Feb 27 2022 Demi Marie Obenour <demi@invisiblethingslab.com> - b528828
- process_io(): block SIGCHLD

* Sun Feb 27 2022 Demi Marie Obenour <demi@invisiblethingslab.com> - abcff74
- process_out(): treat an empty FD_SET properly

* Sun Feb 27 2022 Demi Marie Obenour <demi@invisiblethingslab.com> - 702461f
- Set empty handler for SIGPIPE

